traceservices/tracefw/integ_test/ost/TEF/perfdevicedriver/src/te_drv.cpp
branchRCL_3
changeset 24 cc28652e0254
parent 23 26645d81f48d
--- a/traceservices/tracefw/integ_test/ost/TEF/perfdevicedriver/src/te_drv.cpp	Tue Aug 31 16:57:14 2010 +0300
+++ b/traceservices/tracefw/integ_test/ost/TEF/perfdevicedriver/src/te_drv.cpp	Wed Sep 01 12:39:58 2010 +0100
@@ -48,7 +48,7 @@
  * and loose our state. So we solve this by running the device driver as
  * as it's own separate thread in the kernel (DLogicalChannelBase runs a user thread in kernel mode,
  * DLogicalChannel runs a kernel thread called from a user thread).
  * We also solve the long timing issue by making an asynchrounous call by using the DoRequestL call.
  * For this to work we need to create a DfcQ, i.e. a queue of all the incoming calls from the user side.
  * These then get's run in turn.
  */
@@ -68,7 +68,7 @@
 	// Inherited from DLogicalChannel
 	virtual TInt DoCreate(TInt aUnit, const TDesC8* anInfo, const TVersion& aVer);
 	//Make an asynchronous call...
-	virtual TInt DoRequestL(TInt aReqNo, TRequestStatus* aStatus, TAny* a1, TAny* a2);
+	virtual TInt DoRequest(TInt aReqNo, TRequestStatus* aStatus, TAny* a1, TAny* a2);
 
 	void TestUptTraces(const TApiRunConfig& aApiRunConfig, TApiRunResults& aApiRunResults);
 	void TimeUptTraces(const TApiRunConfig& aApiRunConfig, TApiRunResults& aApiRunResults);
@@ -80,7 +80,7 @@
 	TDfcQue* 		iDfcQ;
 
 	TKernelTimer	iTimer;
  	//This is used to signal when one of the async calls (to DoRequestL) is finished.
  	TRequestStatus	iStatus;
 	};
 
@@ -164,10 +164,10 @@
 		message.Complete(KErrNone, ETrue);
 		return;
 		}
-	if(id < 0 )  //it was a call for DoRequestL()
+	if(id < 0 )  //it was a call for DoRequest()
 		{
 		TRequestStatus* status = (TRequestStatus*)message.Ptr0();
-		DoRequestL(~id, status, message.Ptr1(), message.Ptr2());
+		DoRequest(~id, status, message.Ptr1(), message.Ptr2());
 		message.Complete(KErrNone, ETrue);
 		}
 	else //it was a call for DoControl, we dont implement that now so just fall through
@@ -178,7 +178,7 @@
 		}
 	}
 
-TInt DUptUTraceChannel::DoRequestL(TInt aReqNo, TRequestStatus* aStatus, TAny* a1, TAny* a2)
+TInt DUptUTraceChannel::DoRequest(TInt aReqNo, TRequestStatus* aStatus, TAny* a1, TAny* a2)
 	{
 	TInt error = KErrNone;
 
@@ -258,11 +258,11 @@
 			    	{
 			    	TTestTimer timer;
 			    	if(aReqNo == RUptUTrace::ESanityTestTimer)
-			    		results.iPass = timer.TestKernelTimerL(results.iTime);
+			    		results.iPass = timer.TestKernelTimer(results.iTime);
 			    	if(aReqNo == RUptUTrace::ESanityTestLongTimer)
-			    		results.iPass = timer.TestKernelLongTimerL(results.iTime);
+			    		results.iPass = timer.TestKernelLongTimer(results.iTime);
 			    	if(aReqNo == RUptUTrace::ESanityUtraceTimer)
-			    		results.iPass = timer.TestUTraceKernelTimerL(results.iTime);
+			    		results.iPass = timer.TestUTraceKernelTimer(results.iTime);
 			    	}
 			    if(!error)
 			    	error = Kern::ThreadRawWrite(iClient, a1, (TUint8 *)&results, sizeof(TSanityResults));
@@ -48,7 +48,7 @@
  * as it's own separate thread in the kernel (DLogicalChannelBase runs a user thread in kernel mode,
  * DLogicalChannel runs a kernel thread called from a user thread).
- * We also solve the long timing issue by making an asynchrounous call by using the DoRequestL call.
+ * We also solve the long timing issue by making an asynchrounous call by using the DoRequest call.
  * For this to work we need to create a DfcQ, i.e. a queue of all the incoming calls from the user side.
  * These then get's run in turn.
@@ -80,7 +80,7 @@
 
 	TKernelTimer	iTimer;
- 	//This is used to signal when one of the async calls (to DoRequestL) is finished.
+ 	//This is used to signal when one of the async calls (to DoRequest) is finished.
  	TRequestStatus	iStatus;
 	};